@@ -1,3 +1,5 @@
+from .extended_loader import ExtendedLoader
+from .extended_transformer import ExtendedTransformer
 from .extractor import Extractor
 from .loader import Loader
 from .orchestrator import Orchestrator
@@ -10,5 +12,7 @@ __all__ = [
     "Transformer",
     "Orchestrator",
     "EtlBase",
+    "ExtendedTransformer",
+    "ExtendedLoader",
     "dataset_group",
 ]
