@@ -1,6 +1,13 @@
 from .DataframeCreator import DataframeCreator
 from .DropOldestDuplicates import DropOldestDuplicates
+from .GetMergeStatement import GetMergeStatement
 from .MockExtractor import MockExtractor
 from .MockLoader import MockLoader
 
-__all__ = [DataframeCreator, MockLoader, MockExtractor, DropOldestDuplicates]
+__all__ = [
+    DataframeCreator,
+    MockLoader,
+    GetMergeStatement,
+    MockExtractor,
+    DropOldestDuplicates,
+]
