@@ -13,7 +13,7 @@ from pyspark.sql.types import (
 )
 
 from atc.config_master import TableConfigurator
-from atc.etl.loaders.simple_sql_loader import SimpleSqlServerLoader
+from atc.etl.loaders import SimpleLoader
 from atc.functions import get_unique_tempview_name
 from atc.transformers.simple_sql_transformer import SimpleSqlServerTransformer
 from atc.utils import DataframeCreator
@@ -30,6 +30,7 @@ class SimpleSqlServerETLTests(unittest.TestCase):
     def setUpClass(cls):
         cls.sql_server = DeliverySqlServer()
         cls.tc = TableConfigurator()
+        cls.tc.clear_all_configurations()
 
         # Register the delivery table for the table configurator
         cls.tc.register(
@@ -84,9 +85,7 @@ class SimpleSqlServerETLTests(unittest.TestCase):
             table_id=self.table_id, server=self.sql_server
         ).process(df)
 
-        SimpleSqlServerLoader(table_id=self.table_id, server=self.sql_server).save(
-            df_out
-        )
+        SimpleLoader(handle=self.sql_server.from_tc(self.table_id)).save(df_out)
 
         df_with_data = self.sql_server.read_table(self.table_id)
 
